@@ -15,8 +15,8 @@
 #
 
 import json
+from unittest import mock
 
-import mock
 from osc_lib.tests import utils
 
 from ironicclient.tests.unit.osc import fakes
@@ -152,6 +152,16 @@ TRAITS = ['CUSTOM_FOO', 'CUSTOM_BAR']
 BIOS_SETTINGS = [{'name': 'bios_name_1', 'value': 'bios_value_1', 'links': []},
                  {'name': 'bios_name_2', 'value': 'bios_value_2', 'links': []}]
 
+BIOS_DETAILED_SETTINGS = [{'name': 'SysName', 'value': 'my-system',
+                           'links': [], 'attribute_type': 'String',
+                           'min_length': '1', 'max_length': '16'},
+                          {'name': 'NumCores', 'value': '10',
+                           'links': [], 'attribute_type': 'Integer',
+                           'lower_bound': '10', 'upper_bound': '20'},
+                          {'name': 'ProcVirtualization', 'value': 'Enabled',
+                           'links': [], 'attribute_type': 'Enumeration',
+                           'allowable_values': ['Enabled', 'Disabled']}]
+
 baremetal_volume_connector_uuid = 'vvv-cccccc-vvvv'
 baremetal_volume_connector_type = 'iqn'
 baremetal_volume_connector_connector_id = 'iqn.2017-01.connector'
