@@ -86,6 +86,8 @@ DRIVER_IFACES = {'deploy': {'result': True},
 
 NODE_STATES = {"last_error": None,
                "power_state": "power on",
+               "boot_mode": "fake-efi",
+               "secure_boot": False,
                "provision_state": "active",
                "target_power_state": None,
                "target_provision_state": None}
@@ -410,6 +412,13 @@ fake_responses = {
             None,
         ),
     },
+    '/v1/nodes/%s/states/boot_mode' % NODE1['uuid']:
+    {
+        'PUT': (
+            {},
+            None,
+        ),
+    },
     '/v1/nodes/%s/states/power' % NODE1['uuid']:
     {
         'PUT': (
@@ -417,6 +426,13 @@ fake_responses = {
             POWER_STATE,
         ),
     },
+    '/v1/nodes/%s/states/secure_boot' % NODE1['uuid']:
+    {
+        'PUT': (
+            {},
+            None,
+        ),
+    },
     '/v1/nodes/%s/validate' % NODE1['uuid']:
     {
         'GET': (
@@ -1450,6 +1466,53 @@ class NodeManagerTest(testtools.TestCase):
                           self.mgr.set_power_state,
                           NODE1['uuid'], 'off', soft=False, timeout='a')
 
+    def test_node_set_boot_mode_bios(self):
+        target_state = 'bios'
+        self.mgr.set_boot_mode(NODE1['uuid'], target_state)
+        body = {'target': target_state}
+        expect = [
+            ('PUT', '/v1/nodes/%s/states/boot_mode' % NODE1['uuid'], {}, body),
+        ]
+        self.assertEqual(expect, self.api.calls)
+
+    def test_node_set_boot_mode_invalid(self):
+        self.assertRaises(ValueError, self.mgr.set_boot_mode,
+                          NODE1['uuid'], 'ancient-bios')
+
+    def test_node_set_secure_boot_bool(self):
+        secure_boot = self.mgr.set_secure_boot(NODE1['uuid'], True)
+        body = {'target': True}
+        expect = [
+            ('PUT', '/v1/nodes/%s/states/secure_boot' % NODE1['uuid'],
+             {}, body),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertIsNone(secure_boot)
+
+    def test_node_set_secure_boot_on(self):
+        secure_boot = self.mgr.set_secure_boot(NODE1['uuid'], 'on')
+        body = {'target': True}
+        expect = [
+            ('PUT', '/v1/nodes/%s/states/secure_boot' % NODE1['uuid'],
+             {}, body),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertIsNone(secure_boot)
+
+    def test_node_set_secure_boot_off(self):
+        secure_boot = self.mgr.set_secure_boot(NODE1['uuid'], 'off')
+        body = {'target': False}
+        expect = [
+            ('PUT', '/v1/nodes/%s/states/secure_boot' % NODE1['uuid'],
+             {}, body),
+        ]
+        self.assertEqual(expect, self.api.calls)
+        self.assertIsNone(secure_boot)
+
+    def test_node_set_secure_boot_bad(self):
+        self.assertRaises(exc.InvalidAttribute, self.mgr.set_secure_boot,
+                          NODE1['uuid'], 'band')
+
     def test_set_target_raid_config(self):
         self.mgr.set_target_raid_config(
             NODE1['uuid'], {'fake': 'config'})
@@ -1606,8 +1669,9 @@ class NodeManagerTest(testtools.TestCase):
             ('GET', '/v1/nodes/%s/states' % NODE1['uuid'], {}, None),
         ]
         self.assertEqual(expect, self.api.calls)
-        expected_fields = ['last_error', 'power_state', 'provision_state',
-                           'target_power_state', 'target_provision_state']
+        expected_fields = ['boot_mode', 'last_error', 'power_state',
+                           'provision_state', 'target_power_state',
+                           'target_provision_state', 'secure_boot']
         self.assertEqual(sorted(expected_fields),
                          sorted(states.to_dict().keys()))
 
